@@ -7,7 +7,7 @@ use Exporter 'import';
 use ExtUtils::MakeMaker;
 use XS::Install::Payload;
 
-our $VERSION = '1.0.6';
+our $VERSION = '1.0.7';
 my $THIS_MODULE = 'XS::Install';
 
 our @EXPORT_OK = qw/write_makefile makemaker_args/;
@@ -34,8 +34,6 @@ sub makemaker_args {
     my %params = @_;
     _sync();
 
-    $params{MIN_PERL_VERSION} ||= '5.10.0';
-    
     my $postamble = $params{postamble};
     if ($postamble) {
         my $ref = ref $postamble;
@@ -48,17 +46,7 @@ sub makemaker_args {
     
     _string_merge($params{CCFLAGS}, '-o $@');
 
-    die "You must define a NAME param" unless $params{NAME};
-    unless ($params{ALL_FROM} || $params{VERSION_FROM} || $params{ABSTRACT_FROM}) {
-        my $name = $params{NAME};
-        $name =~ s#::#/#g;
-        $params{ALL_FROM} = "lib/$name.pm";
-    }
-    
-    if (my $package_file = delete $params{ALL_FROM}) {
-        $params{VERSION_FROM}  = $package_file;
-        $params{ABSTRACT_FROM} = $package_file;
-    }
+    process_FROM(\%params);
 
     $params{CONFIGURE_REQUIRES} ||= {};
     $params{BUILD_REQUIRES} ||= {};
@@ -197,6 +185,22 @@ sub process_PM {
     }
 }
 
+sub process_FROM {
+    my $params = shift;
+    my $module = $params->{NAME} or die "You must define a NAME param";
+    
+    if (my $file = delete $params->{ALL_FROM}) {
+        $params->{VERSION_FROM}  = $file;
+        $params->{ABSTRACT_FROM} = $file;
+    }
+    
+    my $pm = 'lib/'._pkg_file($module);
+    my $pod = 'lib/'._pkg_slash($module).'.pod';
+    
+    $params->{VERSION_FROM}  ||= $pm;
+    $params->{ABSTRACT_FROM} ||= (-f $pod) ? $pod : $pm;
+}
+
 sub process_XS {
     my $params = shift;
     $params->{XS} ||= [_scan_files($xs_mask)];
@@ -766,4 +770,12 @@ sub _check_sjlj {
     }
 }
 
+sub _pkg_slash {
+    my $pkg = shift;
+    $pkg =~ s#::#/#g;
+    return $pkg;
+}
+
+sub _pkg_file { return _pkg_slash(shift).'.pm'  }
+
 1;
